## This file runs two sets of survival analyses using dead recovery models. NB, in order for RMark to run, Program MARK (http://www.phidot.org/software/mark/) must first be installed. The first set of models assesses spatial and temporal variation in survival rates. The second assess how well different weather models explain any such temporal variance.


## This first batch of code will run the first set of models to assess spatial and temporal variation, starting by loading and processing the data. 
library("RMark")

setwd("C:/Users/kevin.wood/Documents/Icelandic_Eider_AF_revised/DeadRecoveryModel")

eiders=read.table(file="Eider_dead_recovery.txt",header=TRUE,
                  colClasses=c("character","factor"))

eiders.processed=process.data(eiders,begin.time=1982,model="Recovery",groups=c("site"))

eiders.ddl=make.design.data(eiders.processed)

## Next, specify parameters to be used in the models
Sdot=list(formula=~1)
Stime=list(formula=~time)
Ssite=list(formula=~site)
Stimesite=list(formula=~time+site)
Stime.site=list(formula=~time*site)

rdot=list(formula=~1)
rtime=list(formula=~time)
rsite=list(formula=~site)
rtimesite=list(formula=~time+site)
rtime.site=list(formula=~time*site)

## Run the spatial and temporal models
eiders.Sdot.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rdot))
eiders.Stime.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rdot))
eiders.Ssite.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rdot))
eiders.Stimesite.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rdot))
eiders.Stime.site.rdot=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rdot))
eiders.Sdot.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rtime))
eiders.Stime.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rtime))
eiders.Ssite.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rtime))
eiders.Stimesite.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rtime))
eiders.Stime.site.rtime=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rtime))
eiders.Sdot.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rsite))
eiders.Stime.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rsite))
eiders.Ssite.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rsite))
eiders.Stimesite.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rsite))
eiders.Stime.site.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rsite))
eiders.Sdot.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rtimesite))
eiders.Stime.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rtimesite))
eiders.Ssite.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rtimesite))
eiders.Stimesite.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rtimesite))
eiders.Stime.site.rtimesite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rtimesite))
eiders.Sdot.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Sdot,r=rtime.site))
eiders.Stime.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime,r=rtime.site))
eiders.Ssite.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Ssite,r=rtime.site))
eiders.Stimesite.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stimesite,r=rtime.site))
eiders.Stime.site.rtime.site=mark(eiders.processed, eiders.ddl, model.parameters=list(S=Stime.site,r=rtime.site))


## Collate the model results and adjust for c-hat value (determined in a separate analysis in Program MARK), and export results
model.list=collect.models(type="Recovery")
adjusted.models<-adjust.chat(chat = 1.374, model.list)
my.models<-model.table(adjusted.models)
my.models
write.csv(my.models, "Eider_recovery_models.csv")


## Export parameter estimates from best-supported model
survival.estimates<-get.real(eiders.Stimesite.rsite, "S", se=TRUE)
write.csv(survival.estimates, "realsurvivalestimates2.csv")
recovery.estimates<-get.real(eiders.Stimesite.rsite, "r", se=TRUE)
write.csv(recovery.estimates, "realrecoveryestimates2.csv")

## Remove files before second part of the analysis
cleanup(ask=FALSE)




## This second batch of code will run models to assess the effects of environmental covariates on temporal variation in survival rates.

## For the second set of models, again start by loading and processing the data
library("RMark")

setwd("C:/Users/kevin.wood/Documents/Icelandic_Eider_AF_revised/DeadRecoveryModel")

eiders=read.table(file="Eider_dead_recovery.txt",header=TRUE,
                  colClasses=c("character","factor"))

eiders.processed=process.data(eiders,begin.time=1982,model="Recovery",groups=c("site"))

eiders.ddl=make.design.data(eiders.processed)

## Specify parameters
Sdot=list(formula=~1)
Stime=list(formula=~time)
Ssite=list(formula=~site)

rdot=list(formula=~1)
rtime=list(formula=~time)
rsite=list(formula=~site)

## Specify environmental covariates for the weather models and how they will be used in the models
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1982]=0.9475
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1983]=0.575
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1984]=-0.475
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1985]=0.51
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1986]=-0.1875
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1987]=0.4825
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1988]=1.4075
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1989]=0.69
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1990]=0.48
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1991]=0.5675
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1992]=0.81
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1993]=1.08
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1994]=1.335
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1995]=-0.525
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1996]=0.315
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1997]=0.0475
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1998]=0.54
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==1999]=1.17
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2000]=-0.285
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2001]=0.35
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2002]=0.04
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2003]=0.3075
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2004]=0.21
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2005]=-0.24
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2006]=0.6325
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2007]=0.51
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2008]=0.085
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2009]=-1.475
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2010]=-0.355
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2011]=1.345
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2012]=-0.385
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2013]=0.845
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2014]=1.605
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2015]=1.1675
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2016]=0.675
eiders.ddl$S$WinterNAO[eiders.ddl$S$time==2017]=0.7425

eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1982]=0.0215830048977273
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1983]=-0.142144375079545
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1984]=0.321434455147727
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1985]=-0.0357807226647727
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1986]=-0.439921706653409
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1987]=0.377410180738636
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1988]=-0.0636237723915566
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1989]=-0.124568320505682
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1990]=-0.169985098920455
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1991]=-0.0159543330170454
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1992]=-0.475798857511364
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1993]=0.07708972834375
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1994]=-0.165483771670455
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1995]=0.0876875173090341
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1996]=-0.238955363642045
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1997]=0.68162144625
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1998]=0.335885675647727
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==1999]=0.217030274261364
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2000]=0.331987066931818
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2001]=0.388684182806818
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2002]=1.42311267613636
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2003]=1.05350588636364
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2004]=0.596702754534091
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2005]=0.669211972329546
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2006]=0.138730747175
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2007]=0.645056705892045
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2008]=0.708532967613636
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2009]=0.973661076193182
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2010]=0.874473156363636
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2011]=0.8772629575
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2012]=1.05319459090909
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2013]=0.624705740596591
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2014]=0.775296570244318
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2015]=0.720818731198864
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2016]=0.519013080301136
eiders.ddl$S$WinterSSTa[eiders.ddl$S$time==2017]=0.532289400568182

eiders.ddl$S$SGI[eiders.ddl$S$time==1982]=-15.4438316630097
eiders.ddl$S$SGI[eiders.ddl$S$time==1983]=-17.2856549842851
eiders.ddl$S$SGI[eiders.ddl$S$time==1984]=-18.5244618395303
eiders.ddl$S$SGI[eiders.ddl$S$time==1985]=-18.7473166103303
eiders.ddl$S$SGI[eiders.ddl$S$time==1986]=-17.2558856668445
eiders.ddl$S$SGI[eiders.ddl$S$time==1987]=-17.732787760185
eiders.ddl$S$SGI[eiders.ddl$S$time==1988]=-18.1778252189211
eiders.ddl$S$SGI[eiders.ddl$S$time==1989]=-17.4164739370218
eiders.ddl$S$SGI[eiders.ddl$S$time==1990]=-17.3536934906797
eiders.ddl$S$SGI[eiders.ddl$S$time==1991]=-17.957461108146
eiders.ddl$S$SGI[eiders.ddl$S$time==1992]=-17.7993634979936
eiders.ddl$S$SGI[eiders.ddl$S$time==1993]=-18.2761865227618
eiders.ddl$S$SGI[eiders.ddl$S$time==1994]=-18.8165016110221
eiders.ddl$S$SGI[eiders.ddl$S$time==1995]=-18.3409041491233
eiders.ddl$S$SGI[eiders.ddl$S$time==1996]=-17.7701871948447
eiders.ddl$S$SGI[eiders.ddl$S$time==1997]=-16.9137164205657
eiders.ddl$S$SGI[eiders.ddl$S$time==1998]=-16.4698254561268
eiders.ddl$S$SGI[eiders.ddl$S$time==1999]=-15.1053786396252
eiders.ddl$S$SGI[eiders.ddl$S$time==2000]=-16.3758919923303
eiders.ddl$S$SGI[eiders.ddl$S$time==2001]=-15.9003340647176
eiders.ddl$S$SGI[eiders.ddl$S$time==2002]=-17.0120381901203
eiders.ddl$S$SGI[eiders.ddl$S$time==2003]=-17.6793769396509
eiders.ddl$S$SGI[eiders.ddl$S$time==2004]=-16.7911205993397
eiders.ddl$S$SGI[eiders.ddl$S$time==2005]=-17.6171499733143
eiders.ddl$S$SGI[eiders.ddl$S$time==2006]=-17.8400047441143
eiders.ddl$S$SGI[eiders.ddl$S$time==2007]=-17.9676214196762
eiders.ddl$S$SGI[eiders.ddl$S$time==2008]=-16.7936112593646
eiders.ddl$S$SGI[eiders.ddl$S$time==2009]=-17.4609895431813
eiders.ddl$S$SGI[eiders.ddl$S$time==2010]=-17.8742809701713
eiders.ddl$S$SGI[eiders.ddl$S$time==2011]=-16.9225325663681
eiders.ddl$S$SGI[eiders.ddl$S$time==2012]=-16.7326889244697
eiders.ddl$S$SGI[eiders.ddl$S$time==2013]=-17.209551483524
eiders.ddl$S$SGI[eiders.ddl$S$time==2014]=-16.7339540216252
eiders.ddl$S$SGI[eiders.ddl$S$time==2015]=-16.3536737235367
eiders.ddl$S$SGI[eiders.ddl$S$time==2016]=-17.2114095949712
eiders.ddl$S$SGI[eiders.ddl$S$time==2017]=-17.1802961118029


SWinterNAO=list(formula=~WinterNAO)
SWinterSSTa=list(formula=~WinterSSTa)
SSGI=list(formula=~SGI)
SWinterNAOSSTa=list(formula=~WinterNAO+WinterSSTa)
SWinterNAOSGI=list(formula=~WinterNAO+SGI)
SWinterSSTaSGI=list(formula=~WinterSSTa+SGI)
SWinterNAOSSTaSGI=list(formula=~WinterNAO+WinterSSTa+SGI)


## Run the environmental models. NB you must remove spatial and temporal models before running environmental models, otherwise these will be included in the comparisons of the environmental models
eiders.SWinterNAO.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=SWinterNAO,r=rsite))
eiders.SWinterSSTa.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=SWinterSSTa,r=rsite))
eiders.SSGI.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=SSGI,r=rsite))
eiders.SWinterNAOSSTa.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=SWinterNAOSSTa,r=rsite))
eiders.SWinterNAOSGI.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=SWinterNAOSGI,r=rsite))
eiders.SWinterSSTaSGI.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=SWinterSSTaSGI,r=rsite))
eiders.SWinterNAOSSTaSGI.rsite=mark(eiders.processed, eiders.ddl, model.parameters=list(S=SWinterNAOSSTaSGI,r=rsite))


## Collect environmental model results, adjust for c-hat value, and export 
environmental.model.list=collect.models(type="Recovery")
adjusted.environmental.models<-adjust.chat(chat = 1.374, environmental.model.list)
my.environmental.models<-model.table(adjusted.environmental.models)
my.environmental.models
write.csv(my.environmental.models, "Eider_recovery_environmental_models.csv")




